@@ -111,9 +111,7 @@ fn create_backlink_map(book: &Book) -> HashMap<PathBuf, Vec<Chapter>> {
 
 fn escape_special_chars(text: &str) -> String {
     text.replace(" ", "%20")
-        .replace("<", "&lt;")
-        .replace(">", "&gt;")
-        .replace("'", "&apos;")
-        .replace("\"", "&quot;")
-        .replace("&", "&amp;")
+        .replace("<", "%3C")
+        .replace(">", "%3E")
+        .replace('?', "%3F")
 }
